{ config, pkgs, ... }:

{
  imports = [
    ./modules/gpg.nix
    ./modules/git.nix
    ./modules/alacritty.nix
    ./modules/zellij.nix
    ./modules/helix.nix
  ];
  
  # Do not update without checking the docs first.
  home.stateVersion = "22.11";

  home.packages = with pkgs; [
    (pkgs.nerdfonts.override { fonts = [ "FiraCode" ]; })
    (pkgs.writeShellScriptBin "my-hello" ''
      echo "Hello, ${config.home.username}!"
    '')
    gnome.gnome-tweaks
    unstable.gnomeExtensions.user-themes
    unstable.gnomeExtensions.caffeine
    unstable.gnomeExtensions.blur-my-shell
    unstable.gnomeExtensions.impatience
    unstable.gnomeExtensions.app-menu-is-back
    unstable.gnomeExtensions.dash-to-dock
    unstable.gnomeExtensions.transparent-top-bar
    # gnomeExtensions.window-title-is-back
    
    ungoogled-chromium
    librewolf
    libreoffice
    joplin-desktop
    bitwarden
    authy
  ];

  fonts.fontconfig.enable = true;

  home.file = {
    ".config/helix/".source = ./helix;
    ".config/alacritty/themes/".source = ./alacritty/themes;
  };

  home.sessionVariables = {
    EDITOR = "hx";
  };

  programs.home-manager.enable = true;

  programs.fish = {
    enable = true;
    plugins = [
      { name = "tide"; src = pkgs.fishPlugins.tide.src; }
      { name = "z"; src = pkgs.fishPlugins.z.src; }
    ];
    # TODO: check your config from dotfiles
  };

  # TODO: install keyd or another way to use CapsLock for Esc
  # TODO: color-scheme-monitor?

  programs.fzf = {
    enable = true;
  };

  programs.bat = {
    enable = true;
  };

  programs.nnn = {
    enable = true;
  };

  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
  };

  gtk = {
    enable = true;
    iconTheme = {
      name = "Numix-Circle";
      package = pkgs.numix-icon-theme-circle;
    };

    cursorTheme = {
      name = "Numix-Cursor";
      package = pkgs.numix-cursor-theme;
    };
  };

  home.pointerCursor = {
    name = "Numix-Cursor";
    package = pkgs.numix-cursor-theme;
    size = 36;
    x11.enable = true;
  };

  dconf.settings = {
    "org/gnome/shell" = {
      disable-user-extensions = false;
      enabled-extensions = [
        "caffeine@patapon.info"
        "user-theme@gnome-shell-extensions.gcampax.github.com"
        "appmenu-is-back@fthx"
        # "blur-my-shell@aunetx"
        "transparent-top-bar@zhanghai.me"
        "impatience@gfxmonk.net"
        "dash-to-dock@micxgx.gmail.com"
      ];
    };
    "org/gnome/desktop/interface" = {
      enable-hot-corners = false;
    };
  };
}
