{ pkgs, username, ... }:

let
  vspkgs = {
    vscode-ido = pkgs.vscode-utils.extensionFromVscodeMarketplace {
      # This actually gives me a quite good file selection experience:
      # https://marketplace.visualstudio.com/items?itemName=kimgronqvist.vscode-ido
      publisher = "kimgronqvist";
      name = "vscode-ido";
      version = "0.3.0";
      sha256 = "sha256-Pr3o7FkVu7r0V+PGcs5BRqBh3iXcXOwPRCb2MtoAZJ4=";
    };
    volar = pkgs.vscode-utils.extensionFromVscodeMarketplace {
      # https://marketplace.visualstudio.com/items?itemName=Vue.volar
      publisher = "Vue";
      name = "volar";
      version = "1.8.27";
      sha256 = "sha256-6FktlAJmOD3dQNn2TV83ROw41NXZ/MgquB0RFQqwwW0=";
    };
    php-sniffer = pkgs.vscode-utils.extensionFromVscodeMarketplace {
      # https://marketplace.visualstudio.com/items?itemName=wongjn.php-sniffer
      publisher = "wongjn";
      name = "php-sniffer";
      version = "1.3.0";
      sha256 = "sha256-dPF1CRX9WVQFyC7RZxiPDtIg6+oUituY0qEn5Hipd5Q=";
    };
    php-debug = pkgs.vscode-utils.extensionFromVscodeMarketplace {
      # https://marketplace.visualstudio.com/items?itemName=xdebug.php-debug
      publisher = "xdebug";
      name = "php-debug";
      version = "1.34.0";
      sha256 = "sha256-WAcXWCMmvuw7nkfGcOgmK+s+Nw6XpvNR4POXD85E/So=";
    };
  };
in 
{
  imports = [
    ./common.nix
  ];

  home.username = username;
  home.homeDirectory = "/home/${username}";

  home.packages = with pkgs; [
    firefox # Yuck!
    thunderbird
    slack
    dbeaver
    (unstable.php83.buildEnv {
      extensions = ({ enabled, all }: enabled ++ (with all; [
        xdebug
      ]));
      extraConfig = ''
        xdebug.mode=debug
      '';
    })
    # TODO: move the whole php config to a direnv / some other solution
    unstable.php83Packages.composer
    unstable.php83Packages.php-codesniffer
  ];

  programs.vscode.extensions = [
    pkgs.vscode-extensions.bmewburn.vscode-intelephense-client # Better php support
    vspkgs.volar # Vue support
    vspkgs.vscode-ido # Decent file navigation
    vspkgs.php-sniffer # Php code style sniffing
    vspkgs.php-debug # Php debug support
  ];

  programs.helix.extraPackages = [
    pkgs.nodePackages_latest.intelephense
  ];
}
